=======
History
=======

0.2.2 (2017-06-30)
------------------

* working release with minimal documentation
* works with multiple field matching
* carries out all steps autonomously from string pre-processing to
identifying the strongly connected components


0.1.0 (2017-06-24)
------------------

* First release on PyPI.
